smartcard.CardNames.CardNames

# ``smartcard`.`CardNames`.`CardNames``

class documentation

`class CardNames(object):`

View In Hierarchy

The CardNames organizes cards by a unique name and an associated `smartcard.CardType.CardType`.

Method | `__getattr__` | All operators redirected to inner class.
Method | `__init__` | Constructor: create a single instance of __readergroups on first call
Class Variable | `instance` | Undocumented

def __getattr__(self, name):

All operators redirected to inner class.

def __init__(self):

Constructor: create a single instance of __readergroups on first call

instance =

Undocumented